# [TITLE]

## , 1 January 1970

To the extent possible under law, the editors have waived all copyright and related or neighboring rights to this work. In addition, as of 1 January 1970, the editors have made this specification available under the Open Web Foundation Agreement Version 1.0, which is available at http://www.openwebfoundation.org/legal/the-owf-1-0-agreements/owfa-1-0. Parts of this work may be from another specification document. If so, those parts are instead covered by the license of that specification document.

## Abstract

[ABSTRACT]

Draft: https://www.w3.org/TR/2018/CR-css-paint-api-1-20180809/ Title: CSS Painting API Level 1

Issue 1. Summary: Broken LInks From: Chris Lilley Comment: https://github.com/w3c/css-houdini-drafts/issues/787 Response: https://github.com/w3c/css-houdini-drafts/issues/787#issuecomment-411123499 Closed: Accepted

### Resolved: Editorial

Issue 2. Summary: CSS Paint API leaks browsing history From: Deian Stefan Comment: https://github.com/w3c/css-houdini-drafts/issues/791 Response: https://github.com/w3c/css-houdini-drafts/issues/791#issuecomment-546460085 Changes: https://github.com/w3c/css-houdini-drafts/commit/3c72275054d9d541e6526e2988567ad4d209f257 Closed: Accepted Resolved: Editor discretion

### Verified: https://github.com/w3c/css-houdini-drafts/issues/791#issuecomment-546466424

Issue 3. Summary: Typo: use snappedConcreteObjectSize in paint callback From: Chris Harrelson Comment: https://github.com/w3c/css-houdini-drafts/issues/800 Changes: https://github.com/w3c/css-houdini-drafts/commit/735ea42edf09f8d69de1eddbc7e7691528f56963 Closed: Accepted

### Resolved: Editorial

Issue 4. Summary: Disconnect between css-paint-api-1 and HTML specs on CanvasImageSource From: Alan Jeffrey Comment: https://github.com/w3c/css-houdini-drafts/issues/819 Response: https://github.com/w3c/css-houdini-drafts/issues/819#issuecomment-424360647

### Open: Waiting for HTML spec edits

Issue 5. Summary: Improve passing of large-scale data to PaintWorklet From: John Wiesz Comment: https://github.com/w3c/css-houdini-drafts/issues/872 Response: https://github.com/w3c/css-houdini-drafts/issues/872#issuecomment-499903766

### Open: Waiting on edits to add new features to Properties an Values API

Issue 6. Summary: Cycle possibe using inputProperties() From: Stephen McGruer Comment: https://github.com/w3c/css-houdini-drafts/issues/877 Response: https://github.com/w3c/css-houdini-drafts/issues/877#issuecomment-499922873

### Open: Needs Edits

Issue 7. Summary: Two-way communication between main thread and worklet From: Samad Aghaei Comment: https://github.com/w3c/css-houdini-drafts/issues/881 Response: https://github.com/w3c/css-houdini-drafts/issues/881#issuecomment-546456591

### Closed: OutOfScope

## Conformance

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

## References

### Normative References

[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119